Returns the maxima and minima of the input values.
max_gc(..., na.rm = TRUE, allmissing_NA = TRUE)min_gc(..., na.rm = TRUE, allmissing_NA = TRUE)
If allmissing_NA = FALSE, identical to min or
max.
If allmissing_NA = TRUE, identical to min or
max except that, in cases where min or
max would return an infinite value and raise a warning because
there are no non-missing arguments, min_gc and
max_gc return NA
numeric or character arguments
a logical indicating whether missing values should be removed.
a logical indicating whether NA should be
returned when there are no non-missing arguments
passed to min or max (often because
na.rm = TRUE but all values are NA)
These functions are wrappers for min and max,
with the additional argument allmissing_NA.