This function is a wrapper for smooth.spline, which fits
a cubic smoothing spline to the supplied data, but includes the option
to remove NA values, and returns values in the original order.
gc_smooth.spline(x, y = NULL, ..., na.rm = TRUE)Similar to smooth.spline, an object of class
"smooth.spline" with many components. Differs in that
x, y, and w have NA's at any indices where x or y were
NA in the inputs, and x, y, and w are returned to match the input
x in order and length
A vector giving the values of the predictor variable.
A vector giving the values of the response variable. If y is
missing or NULL, the responses are assumed to be specified
by x, with x the index vector.
Additional arguments passed to smooth.spline.
logical whether NA's should be removed before analyzing.
Required to be TRUE if any x or y values are NA.
See smooth.spline