Takes blocks and returns them in a wide format
trans_block_to_wide(
blocks,
wellnames_sep = "",
nested_metadata = NULL,
colnames_first = FALSE
)A single wide-shaped dataframe
Blocks, either a single dataframe or a list of dataframes
String to use as separator for well names between
row name and column name (ordered according to
colnames_first
A logical indicating the existence of nested metadata
in the blockmeasures list, e.g. as is typically
output by read_blocks. If NULL, will
attempt to infer existence of nested metadata
In the wellnames created by paste-ing the rownames and column names, should the column names come first?